package baleine.common.interfaces.client;

import baleine.common.dataModel.Board;
import baleine.common.dataModel.GameHeavy;
import baleine.common.dataModel.GameLight;
import baleine.common.dataModel.Message;
import baleine.common.dataModel.UserLight;
import javafx.scene.Scene;

public interface IDataToGame {
	/**
	 * Updates the game board using the given board information
	 * 
	 * @param b : Board information to display
	 */
	public void updateInterface(Board b);

	/**
	 * Displays a confirmation popup asking if the user wants to save the game
	 */
	public void displaySaveConfirmation();

	/**
	 * Shows a new message into the chat panel
	 * 
	 * @param m : Message to display
	 */
	public void displayMessage(Message m);

	/**
	 * Shows the specified player profile panel
	 * 
	 * @param usr : User to display the profil from
	 */
	public void displayPlayerProfile(UserLight usr);

	/**
	 * Init method of the game IHM, <b>for the players</b>. Displays the game main
	 * panel.
	 * 
	 * @param gl : Game data
	 * @param sc : JavaFX Scene (shared with IHM-MAIN module)
	 */
	public void getGameScreen(GameLight gl, Scene sc);

	/**
	 * Init method of the game IHM, <b>for the spectators</b>. Displays the game
	 * main panel.
	 * 
	 * @param gl : Game data
	 * @param sc : JavaFX Scene (shared with IHM-MAIN module)
	 */
	public void beginGameDisplay(GameLight gl, Scene sc);

	/**
	 * Displays a message into the chat panel that the specified user joined the
	 * game as a spectator.
	 * 
	 * @param spectator : New spectator
	 */
	public void displayUserJoinedMessage(GameLight spectator);

	/**
	 * Replays the specified game
	 * 
	 * @param game : Game to replay
	 * @param sc   : JavaFX Scene (shared with IHM-MAIN module)
	 */
	public void replayGame(GameHeavy game, Scene scene);
}
